package jaredbgreat.dldungeons.builder;

/*This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/	


import jaredbgreat.dldungeons.planner.Dungeon;

import java.util.Random;

import net.minecraft.block.Block;
import net.minecraft.block.material.Material;
import net.minecraft.tileentity.TileEntityMobSpawner;
import net.minecraft.world.World;
import net.minecraft.world.chunk.IChunkProvider;

public class Builder {
	private static final Block air = (Block)Block.getBlockFromName("air");
	private static final Block spawner = (Block)Block.getBlockFromName("mob_spawner");
		
	
	public static void placeBlock(World world, int x, int y, int z, Block block) {
		// This wrapper is a protection against possible changes in block representation,
		// e.g., abandoning the ID system, allowing any needed changes to be made here
		if(block == null) { 
			world.setBlock(x, y, z, air);
			return;
		}
		// instead of elsewere. 
		//Block.field_149771_c.getObject("stone");
		world.setBlock(x, y, z, block);
	}
	
	
	public static void placeBlock(World world, int x, int y, int z, Block block, int a, int b) {
		// This wrapper is a protection against possible changes in block representation,
		// e.g., abandoning the ID system, allowing any needed changes to be made here
		if(block == null) { 
			world.setBlockToAir(x, y, z);
			return;
		}
		// instead of elsewhere. 
		//FIXME -- clearly the wrong function; this places natural biome blocks
		//FIXME    I need to place the right blocks with mata-data.
		world.setBlock(x, y, z, block, a, b);
	}
	
	
	public static void deleteBlock(World world, int x, int y, int z) {
		// This wrapper is a protection against possible changes in block representation,
		// e.g., abandoning the ID system, allowing any needed changes to be made here
		// instead of elsewere. 
		world.setBlock(x, y, z, air);
	}
	
	
	public static void placeSpawner(World world, int x, int y, int z, String mob) {
		placeBlock(world, x, y, z, spawner);
		TileEntityMobSpawner theSpawner = (TileEntityMobSpawner)world.getTileEntity(x, y, z);
		theSpawner.func_145881_a().setEntityName(mob);
		//world.setBlockMetadataWithNotify(x, y, z, 15, 7);
	}
	
	
	public static boolean isGroundBlock(World world, int x, int y, int z) {
		Material mat = ((Block)world.getBlock(x, y, z)).getMaterial();
		return 	   (mat == Material.grass) 
				|| (mat == Material.iron) 
				|| (mat == Material.ground) 
				|| (mat == Material.sand) 
				|| (mat == Material.rock) 
				|| (mat == Material.clay)
				|| (mat == Material.coral);
	}
	

	public static void placeDungeon(Random random, int chunkX, int chunkZ, World world) throws Throwable {	
		if(world.isRemote) return; // Do not perform world-gen on the client!
		//Debug Code
		System.out.println("Running Builder.placeDungeon; generating dungeon");
		Dungeon dungeon = new Dungeon(random, 
					world.getBiomeGenForCoords((chunkX * 16), (chunkZ * 16)), 
					world, chunkX, chunkZ);

		System.out.println("Running Builder.buildDungeon; building dungeon");
		if(dungeon != null) dungeon.build();
		System.out.println("Dungeon should be built now!");
		dungeon.finalize();
		dungeon = null;
	}
}
